@@ -205,6 +205,11 @@ def dl_download(args=None) -> None:
         ╘═════════════════════╧════════════╧══════════════════╧════════════════════╧══════════╛
     """,
     )
+
+    if "media" in args.db.table_names() and "webpath" in args.db["media"].columns_dict:
+        with args.db.conn:
+            args.db.conn.execute("DELETE from media WHERE webpath is NULL and path in (select webpath from media)")
+
     media = process_downloadqueue(args)
     for m in media:
         if args.safe and not tube_backend.is_supported(m["path"]):
